@@ -68,6 +68,14 @@ Gravatar::URL
 
 Net::Domain
 
+Net::POP3 - used for POP3 access, for example: Bounce Handler and Bridge
+
+Net::SMTP - used for sending via SMTP
+
+Digest::HMAC
+
+Authen::SASL
+
 JSON - actually required for Dada Mail - Pure Perl version included, but you probably want to use a faster version
 
 MIME::Base64
